@@ -49,7 +49,6 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('agent/tunnel_csum').with_value(['<SERVICE DEFAULT>'])
       should contain_neutron_agent_ovs('ovs/datapath_type').with_value(['<SERVICE DEFAULT>'])
       should contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('ovs/ovsdb_interface').with_value(['<SERVICE DEFAULT>'])
       should contain_neutron_agent_ovs('ovs/ovsdb_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_connect_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/of_request_timeout').with_value('<SERVICE DEFAULT>')
@@ -65,12 +64,6 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('ovs/int_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('agent/tunnel_types').with_ensure('absent')
-      should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
-        with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
-        with_value('<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(['<SERVICE DEFAULT>'])
     end
 
     it 'installs neutron ovs agent package' do
@@ -317,25 +310,6 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
-    context 'when supplying ovsdb_interface' do
-      context 'with incorrect value' do
-        before :each do
-          params.merge!(:ovsdb_interface => 'random')
-        end
-
-        it { should raise_error(Puppet::Error, /A value of \$ovsdb_interface is incorrect. The allowed values are vsctl and native/) }
-      end
-
-      context 'with supported value' do
-        before :each do
-          params.merge!(:ovsdb_interface => 'native')
-        end
-        it 'should configure ovsdb_interface for ovs' do
-          should contain_neutron_agent_ovs('ovs/ovsdb_interface').with_value('native')
-        end
-      end
-    end
-
     context 'when enabling dpdk with manage vswitch disabled' do
       before :each do
         params.merge!(:enable_dpdk => true, :manage_vswitch => false)
@@ -343,23 +317,6 @@ describe 'neutron::agents::ml2::ovs' do
 
       it { should raise_error(Puppet::Error, /Enabling DPDK without manage vswitch does not have any effect/) }
     end
-
-    context 'when parameters for resource providers are set' do
-      before :each do
-        params.merge!(
-          :resource_provider_bandwidths  => ['provider-a', 'provider-b'],
-          :resource_provider_hypervisors => ['provider-a:compute-a', 'provider-b:compute-b'],
-        )
-      end
-
-      it 'configures resource providers' do
-        should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
-          with_value('provider-a,provider-b')
-        should contain_neutron_agent_ovs('ovs/resource_provider_hypervisors').\
-          with_value('provider-a:compute-a,provider-b:compute-b')
-      end
-    end
-
   end
 
   shared_examples 'neutron::agents::ml2::ovs on Debian' do
@@ -400,26 +357,6 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
-    context 'with IGMP snooping enabled' do
-      before :each do
-        params.merge!(:igmp_snooping_enable => true)
-      end
-
-      it 'configure neutron/plugins/ml2/ml2_conf.ini' do
-        should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value(true)
-      end
-    end
-
-    context 'with direct output enabled for egress flows' do
-      before :each do
-        params.merge!(:explicitly_egress_direct => true)
-      end
-
-      it 'configure neutron/plugins/ml2/ml2_conf.ini' do
-        should contain_neutron_agent_ovs('agent/explicitly_egress_direct').with_value(true)
-      end
-    end
-
   end
 
   on_supported_os({
