@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'neutron::server' do
   let :pre_condition do
     "class { 'neutron': }
-     class { '::neutron::keystone::authtoken':
+     class { 'neutron::keystone::authtoken':
        password => 'passw0rd',
      }"
   end
@@ -77,7 +77,6 @@ describe 'neutron::server' do
         :max_request_body_size        => '<SERVICE DEFAULT>',
       )
       should contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>')
-      should contain_neutron_config('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -230,8 +229,8 @@ describe 'neutron::server' do
 
       let :pre_condition do
         "class { 'neutron': }
-         include ::apache
-         class { '::neutron::keystone::authtoken':
+         include apache
+         class { 'neutron::keystone::authtoken':
            password => 'passw0rd',
          }"
       end
@@ -269,16 +268,6 @@ describe 'neutron::server' do
       it { should contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('br-int') }
     end
 
-    context 'with IGMP snooping enabled' do
-      before :each do
-        params.merge!(:igmp_snooping_enable => true)
-      end
-
-      it 'configure neutron.conf' do
-        should contain_neutron_config('ovs/igmp_snooping_enable').with_value(true)
-      end
-    end
-
   end
 
   shared_examples 'VPNaaS and FWaaS package installation' do
